@@ -331,7 +331,7 @@ class FinTS3Client:
 
         You should only call this method once, and only immediately after constructing
         the object and before calling any other method or functionality (e.g. __enter__()).
-        For convenience, you can pass the `set_data` parameter to __init__()."""
+        For convenience, you can pass the `from_data` parameter to __init__()."""
         decompress_datablob(DATA_BLOB_MAGIC, blob, self)
 
     def _log_response(self, segment, response):
@@ -546,6 +546,15 @@ class FinTS3Client:
 
         return response
 
+    @staticmethod
+    def _response_handler_get_transactions_xml(responses):
+        booked_streams = []
+        pending_streams = []
+        for seg in responses:
+            booked_streams.extend(seg.statement_booked.camt_statements)
+            pending_streams.append(seg.statement_pending)
+        return booked_streams, pending_streams
+
     def get_transactions_xml(self, account: SEPAAccount, start_date: datetime.date = None,
                              end_date: datetime.date = None) -> list:
         """
@@ -573,17 +582,12 @@ class FinTS3Client:
                     touchdown_point=touchdown,
                     supported_camt_messages=SupportedMessageTypes(['urn:iso:std:iso:20022:tech:xsd:camt.052.001.02']),
                 ),
-                lambda responses: responses,  # TODO
+                FinTS3Client._response_handler_get_transactions_xml,
                 'HICAZ'
             )
             logger.info('Fetching done.')
 
-        booked_streams = []
-        pending_streams = []
-        for seg in responses:
-            booked_streams.extend(seg.statement_booked.camt_statements)
-            pending_streams.append(seg.statement_pending)
-        return booked_streams, pending_streams
+        return responses
 
     def get_credit_card_transactions(self, account: SEPAAccount, credit_card_number: str, start_date: datetime.date = None, end_date: datetime.date = None):
         # FIXME Reverse engineered, probably wrong
@@ -1344,8 +1348,16 @@ class FinTS3PinTanClient(FinTS3Client):
         """Get information about TAN lists/generators.
 
         Returns tuple of fints.formals.TANUsageOption and a list of fints.formals.TANMedia4 or fints.formals.TANMedia5 objects."""
+        if self.connection.url == 'https://hbci.postbank.de/banking/hbci.do':
+            # see https://github.com/raphaelm/python-fints/issues/101#issuecomment-572486099
+            context = self._new_dialog(lazy_init=True)
+            method = lambda dialog: dialog.init
+        else:
+            context = self._get_dialog()
+            method = lambda dialog: dialog.send
 
-        with self._get_dialog() as dialog:
+
+        with context as dialog:
             hktab = self._find_highest_supported_command(HKTAB4, HKTAB5)
 
             seg = hktab(
@@ -1357,7 +1369,7 @@ class FinTS3PinTanClient(FinTS3Client):
 
             try:
                 self._bootstrap_mode = True
-                response = dialog.send(seg)
+                response = method(dialog)(seg)
             finally:
                 self._bootstrap_mode = False
 
